# PaiPage
PaiPage is an open-source CMS built upon Python & Django. It aims to be simple yet powerful enough to support languages and themes out of box.

Project tasks are in [this Google Sheet](https://docs.google.com/spreadsheets/d/1mJxt3Kc-PXq5yUyVxZ3PmTBJviC2u6RBQyOaL-_gjws).
